Card class

Constructors

Card({required int quantity, required String name, required String set, required String code, required CardType cardType})
const
Card.fromString({required String string, required CardType cardType})
factory

Properties

cardType CardType
final
code String
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
quantity int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
set String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override