PTCGListParserResult class

Constructors

PTCGListParserResult({required List<Card> cards})

Properties

cards List<Card>
final
energies List<Card>
no setter
hashCode int
The hash code for this object.
no setteroverride
pokemon List<Card>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trainers List<Card>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override